# PySentry - pip-audit Benchmark Report

**Generated:** 2026-01-21 14:30:55
**Duration:** 1m 44.50s
**Total Tests:** 20

## Executive Summary

**Overall Success Rate:** 100.0% (20/20 successful runs)

### Small_Requirements Dataset - Cold Cache
- **Fastest:** pysentry-pypi (0.234s) - 36.30x faster than slowest
- **Memory Efficient:** pysentry-osv (10.41 MB) - 7.50x less memory than highest

### Small_Requirements Dataset - Hot Cache
- **Fastest:** pysentry-pypi (0.278s) - 28.49x faster than slowest
- **Memory Efficient:** pysentry-osv (9.52 MB) - 8.85x less memory than highest

### Large_Requirements Dataset - Cold Cache
- **Fastest:** pysentry-pypi (0.689s) - 23.81x faster than slowest
- **Memory Efficient:** pysentry-pypi (8.10 MB) - 10.03x less memory than highest

### Large_Requirements Dataset - Hot Cache
- **Fastest:** pysentry-pypi (0.727s) - 21.48x faster than slowest
- **Memory Efficient:** pysentry-osv (9.44 MB) - 7.24x less memory than highest

## Test Environment

- **Platform:** Linux-6.11.0-1018-azure-x86_64-with-glibc2.39
- **Python Version:** 3.11.14
- **CPU Cores:** 4
- **Total Memory:** 15.62 GB
- **Available Memory:** 14.70 GB

## Performance Comparison

### Small_Requirements Dataset - Cold Cache

#### Execution Time Comparison

| Tool Configuration | Execution Time | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-pypi | 0.234s | 1.00x |
| 🥈 pysentry-osv | 0.703s | 3.01x |
|  pysentry-all-sources | 0.814s | 3.48x |
|  pysentry-pypa | 0.946s | 4.05x |
|  pip-audit-default | 8.483s | 36.30x |

#### Memory Usage Comparison

| Tool Configuration | Peak Memory | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-osv | 10.41 MB | 1.00x |
| 🥈 pysentry-pypi | 10.61 MB | 1.02x |
|  pip-audit-default | 45.68 MB | 4.39x |
|  pysentry-pypa | 60.80 MB | 5.84x |
|  pysentry-all-sources | 78.09 MB | 7.50x |

### Small_Requirements Dataset - Hot Cache

#### Execution Time Comparison

| Tool Configuration | Execution Time | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-pypi | 0.278s | 1.00x |
| 🥈 pysentry-osv | 0.596s | 2.15x |
|  pysentry-pypa | 0.689s | 2.48x |
|  pysentry-all-sources | 0.787s | 2.83x |
|  pip-audit-default | 7.911s | 28.49x |

#### Memory Usage Comparison

| Tool Configuration | Peak Memory | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-osv | 9.52 MB | 1.00x |
| 🥈 pysentry-pypi | 11.76 MB | 1.24x |
|  pysentry-pypa | 44.37 MB | 4.66x |
|  pip-audit-default | 44.39 MB | 4.66x |
|  pysentry-all-sources | 84.27 MB | 8.85x |

### Large_Requirements Dataset - Cold Cache

#### Execution Time Comparison

| Tool Configuration | Execution Time | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-pypi | 0.689s | 1.00x |
| 🥈 pysentry-pypa | 1.436s | 2.09x |
|  pysentry-osv | 2.601s | 3.78x |
|  pysentry-all-sources | 2.914s | 4.23x |
|  pip-audit-default | 16.396s | 23.81x |

#### Memory Usage Comparison

| Tool Configuration | Peak Memory | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-pypi | 8.10 MB | 1.00x |
| 🥈 pysentry-osv | 9.73 MB | 1.20x |
|  pip-audit-default | 48.19 MB | 5.95x |
|  pysentry-pypa | 55.50 MB | 6.85x |
|  pysentry-all-sources | 81.25 MB | 10.03x |

### Large_Requirements Dataset - Hot Cache

#### Execution Time Comparison

| Tool Configuration | Execution Time | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-pypi | 0.727s | 1.00x |
| 🥈 pysentry-pypa | 1.128s | 1.55x |
|  pysentry-osv | 2.619s | 3.60x |
|  pysentry-all-sources | 3.012s | 4.14x |
|  pip-audit-default | 15.624s | 21.48x |

#### Memory Usage Comparison

| Tool Configuration | Peak Memory | Relative Performance |
|---------------------|---------------------|---------------------|
| 🥇 pysentry-osv | 9.44 MB | 1.00x |
| 🥈 pysentry-pypi | 12.60 MB | 1.33x |
|  pip-audit-default | 47.27 MB | 5.01x |
|  pysentry-pypa | 60.44 MB | 6.40x |
|  pysentry-all-sources | 68.34 MB | 7.24x |

## Detailed Analysis

### Pysentry Performance

- **Execution Time:** Avg: 1.261s, Min: 0.234s, Max: 3.012s

- **Memory Usage:** Avg: 38.45 MB, Min: 8.10 MB, Max: 84.27 MB

- **Success Rate:** 100.0% (16/16)

### Pip-Audit Performance

- **Execution Time:** Avg: 12.104s, Min: 7.911s, Max: 16.396s

- **Memory Usage:** Avg: 46.38 MB, Min: 44.39 MB, Max: 48.19 MB

- **Success Rate:** 100.0% (4/4)